# mvinstall

A public CLI tool for installing Movandi data and packages from S3.


## Installation

Regular users can install `mvinstall` via:
```
$ pip install mvinstall
```

Developers can install from the project directory:
```
$ pip install -e .
```


## Example usage

```
$ mvinstall  # Get a list of available commands
$ mvinstall --init token  # Initialize / configure based on token generated by mvconfig
$ mvinstall --sync  # Sync local versions of data and packages
$ mvinstall --upgrade  # Equivalent of pip install mvgui --upgrade
```

## Developer tools

Also see [the notes for developers](https://github.com/movandi/mvconfig/blob/master/DEVELOPERS.md).

```
$ invoke -l  # See all dev commands
$ invoke autoformat  # Autoformat the code
$ invoke lint  # Check linting errors (e.g. unused/undefined variables)
$ invoke test  # Run pytest
```

Note: since the tests involve creation and deletion of S3 buckets and IAM users,
the tests should probably be run by one developer at a time ...

Releasing (you need a Pypi account registered as a maintainer for mvinstall):

* `git pull` to make sure you actually have the latest version.
* Update the `__version__` in `__init__.py`.
* `git commit -m "bump version"`
* `invoke clean`  just in case.
* `python setup.py bdist_wheel` to generate the distributable packge.
* `twine upload dist/*` to upload to Pypi.


### The purpose of mvinstall

The `mvinstall` CLI is used by clients to install the necessary
libraries, board configs etc. on the client's Python environment. 

The core of mvinstall is the `s3install` module, which is completely
"Movandi-unaware". The rest of mvinstall is a small wrapper around it.

This generalization is made possible by means of a small config file.
The mvconfig library/cli is responsible for creating an appropriate
config file (e.g. pointing to the right movandi buckets) and uploading
it to an S3 bucket.

For reference, the config file can have the following fields:

- host: The S3 (compatible) provbider, e.g. "s3.amazonaws.com".
- access_key: The access key id.
- secret_key: The secret part of the credentials.
- always_install: A list of packages to install by default when install/upgrade is used.
- config_location: The "bucketname/prefix" where "config.json" is located.
- package_locations: A dictionary that maps local directories to "bucketname/prefix".
- data_locations: A dictionary that maps local directories to "bucketname/prefix".
